@@ -160,6 +160,10 @@ def UnInstall(Library):
         os.system(f"{sys.executable} -m pip uninstall {Library} ")
 
 
+def Empty_Func():
+    pass
+
+
 class AccentState(Enum):
     ACCENT_DISABLED = 0,
     ACCENT_ENABLE_GRADIENT = 1,
@@ -280,11 +284,23 @@ class DevManage(object):
         self.DwmApi = ctypes.windll.dwmapi
         self.Win32 = ctypes.windll.user32
         self.UXTheme = ctypes.windll.uxtheme
+        self.Shcore = ctypes.windll.shcore
         self.DwmSetWindowAttribute = self.DwmApi.DwmSetWindowAttribute
         self.DwmGetWindowAttribute = self.DwmApi.DwmGetWindowAttribute
         self.DwmGetColorizationColor = self.DwmApi.DwmGetColorizationColor
+        self.DwmEnableBlurBehindWindow = self.DwmApi.DwmEnableBlurBehindWindow
+        self.DwmIsCompositionEnabled = self.DwmApi.DwmIsCompositionEnabled
+        self.DwmExtendFrameIntoClientArea = self.DwmApi.DwmExtendFrameIntoClientArea
+        self.DwmRegisterThumbnail = self.DwmApi.DwmRegisterThumbnail
+
         self.SetWindowCompositionAttribute = self.Win32.SetWindowCompositionAttribute
 
+        self.DWMSBT_AUTO = 0
+        self.DWMSBT_NONE = 1
+        self.DWMSBT_MAINWINDOW = 2
+        self.DWMSBT_TRANSIENTWINDOW = 3
+        self.DWMSBT_TABBEDWINDOW = 4
+
         self.DWMNCRP_USEWINDOWSTYLE = 0
         self.DWMNCRP_DISABLED = 1
         self.DWMNCRP_ENABLED = 2
@@ -325,16 +341,38 @@ class DevManage(object):
         self.DWMWA_USE_HOSTBACKDROPBRUSH = 17
         self.DWMWA_CAPTION_COLOR = 19
         self.DWMWA_USE_IMMERSIVE_DARK_MODE = 20
-        self.DWMWA_SYSTEMBACKDROP_TYPE = 23
         self.DWMWA_LAST = 24
         self.DWMWA_WINDOW_CORNER_PREFERENCE = 33
         self.DWMWA_BORDER_COLOR = 34
         self.DWMWA_TEXT_COLOR = 36
         self.DWMWA_VISIBLE_FRAME_BORDER_THICKNESS = 37
+        self.DWMWA_SYSTEMBACKDROP_TYPE = 38
+
+        self.DWMSC_DOWN = 0
+        self.DWMSC_UP = 1
+        self.DWMSC_DRAG = 2
+        self.DWMSC_HOLD = 3
+        self.DWMSC_PENBARREL = 4
+        self.DWMSC_NONE = 5
+        self.DWMSC_ALL = 6
+
+        self.rgbRed = 0x000000FF
+        self.rgbGreen = 0x0000FF00
+        self.rgbBlue = 0x00FF0000
+        self.rgbBlack = 0x00000000
+        self.rgbWhite = 0x00FFFFFF
+
+    def high_dpi(self):
+        try:
+            self.Shcore.SetProcessDpiAwareness(2)
+        except:
+            self.Win32.SetProcessDPIAware()
+        ScaleFactor = self.Shcore.GetScaleFactorForDevice(0)
+        self._master_tk.tk.call('tk', 'scaling', ScaleFactor / 75)
 
     def window_screenshot(self):
         from tkcap import CAP
-        return CAP(window).capture(image_name)
+        return CAP(self._master).capture(image_name)
 
     def dwm_set_window_attribute(self, type, attribute, size):
         """
@@ -369,6 +407,47 @@ class DevManage(object):
             ctypes.sizeof(Value)
         )
 
+    def dwm_set_window_attribute_systembackdrop_type(self, type=1):
+        Value = ctypes.c_int(type)
+        self.dwm_set_window_attribute(self.DWMWA_SYSTEMBACKDROP_TYPE, ctypes.byref(Value), ctypes.sizeof(Value))
+
+    def dwm_set_window_attribute_systembackdrop_type_auto(self):
+        self.dwm_set_window_attribute_systembackdrop_type(self.DWMSBT_AUTO)
+
+    def dwm_set_window_attribute_systembackdrop_type_none(self):
+        self.dwm_set_window_attribute_systembackdrop_type(self.DWMSBT_NONE)
+
+    def dwm_set_window_attribute_systembackdrop_type_mainwindow(self):
+        self.dwm_set_window_attribute_systembackdrop_type(self.DWMSBT_MAINWINDOW)
+
+    def dwm_set_window_attribute_systembackdrop_type_transient_window(self):
+        self.dwm_set_window_attribute_systembackdrop_type(self.DWMSBT_TRANSIENTWINDOW)
+
+    def dwm_set_window_attribute_systembackdrop_type_tabbed_window(self):
+        self.dwm_set_window_attribute_systembackdrop_type(self.DWMSBT_TABBEDWINDOW)
+
+    def dwm_set_window_attribute_visible_frame_border_thickness(self, value):
+        self.Value = ctypes.c_int(value)
+        self.dwm_set_window_attribute(self.DWMWA_VISIBLE_FRAME_BORDER_THICKNESS, ctypes.byref(self.Value),
+                                      ctypes.sizeof(self.Value))
+
+    def dwm_set_window_attribute_ncrendering_policy(self, value=2):
+        Value = ctypes.c_int(value)
+        self.dwm_set_window_attribute(self.DWMWA_NCRENDERING_POLICY,
+                                      ctypes.byref(Value), ctypes.sizeof(Value))
+
+    def dwm_set_window_attribute_border_color(self, color=0x00FF0000):
+        Value = ctypes.c_int(color)
+        self.dwm_set_window_attribute(self.DWMWA_BORDER_COLOR, ctypes.byref(Value), ctypes.sizeof(Value))
+
+    def dwm_set_window_attribute_text_color(self, color=0x00FF0000):
+        Value = ctypes.c_int(color)
+        self.dwm_set_window_attribute(self.DWMWA_TEXT_COLOR, ctypes.byref(Value), ctypes.sizeof(Value))
+
+    def dwm_set_window_attribute_caption_color(self, color=0x00FF0000):
+        Value = ctypes.c_int(color)
+        self.dwm_set_window_attribute(self.DWMWA_CAPTION_COLOR, ctypes.byref(Value), ctypes.sizeof(Value))
+
     def dwm_set_window_round(self, value):
         Value = ctypes.c_int(value)
         self.dwm_set_window_attribute(
@@ -402,11 +481,6 @@ class DevManage(object):
     def dwm_get_colorization_color(self):
         return self.DwmGetColorizationColor()
 
-    def dwm_set_ncrendering_policy(self, value=2):
-        Value = ctypes.c_int(value)
-        self.dwm_set_window_attribute(self.DWMWA_NCRENDERING_POLICY,
-                                      ctypes.byref(Value), ctypes.sizeof(Value))
-
     def dwm_enable_blurbehind_window(self, flags=0x00000001, enable: bool = True, rgn_blur=1,
                                      transition_on_maximized: bool = True):
         BlurBehid = DWM_BLURBEHIND()
@@ -414,14 +488,17 @@ class DevManage(object):
         BlurBehid.fEnable = enable
         BlurBehid.hRgnBlur = rgn_blur
         BlurBehid.TransitionOnMaximized = transition_on_maximized
-        return self.DwmApi.DwmEnableBlurBehindWindow(self._master, ctypes.byref(BlurBehid))
+        return self.DwmEnableBlurBehindWindow(self._master, ctypes.byref(BlurBehid))
 
     def dwm_is_composition_enabled(self):
-        return self.DwmApi.DwmIsCompositionEnabled()
+        return self.DwmIsCompositionEnabled()
 
     def dwm_extend_frame_into_client_area(self, margins=[-1, -1, -1, -1]):
         Margins = MARGINS(margins[0], margins[1], margins[2], margins[3])
-        return self.DwmApi.DwmExtendFrameIntoClientArea(self._master, ctypes.byref(Margins))
+        return self.DwmExtendFrameIntoClientArea(self._master, ctypes.byref(Margins))
+
+    def dwm_register_thumbnail(self, id):
+        return self.DwmRegisterThumbnail(self._master, self.find_window("Program", NULL), id)
 
     def use_mica(self, is_dark=False):
         """
@@ -494,6 +571,9 @@ class DevManage(object):
     def enable_theming(self, bool: bool):
         return self.UXTheme.EnableTheming(bool)
 
+    def find_window(self, Class, Name):
+        return FindWindow(Class, Name)
+
     def set_master(self, master: tk.Tk):
         """
         设置组件的父组件。
@@ -1388,14 +1468,14 @@ class DevTabbar(tk.Frame):
 
 
 class DevWindow(tk.Tk):
-    def __init__(self, title: str = ""):
+    def __init__(self, title: str = "", size=(630,300), icon=Icon_Empty):
         """
         快捷使用窗口，内置多种功能，快速使用
         """
         super(DevWindow, self).__init__()
         self.title(title)
-        self.geometry("630x300")
-        self.iconbitmap(Icon_Empty)
+        self.geometry(f"{size[0]}x{size[1]}")
+        self.iconbitmap(icon)
         self.configure(background="#ffffff")
 
     def wm_remove_titlebar(self):
@@ -1510,13 +1590,17 @@ class DevWindow(tk.Tk):
         """
         self.tk.call('tk', 'scaling', ScaleFactor / 75)
 
+    def can_darg_file(self, func=Empty_Func):
+        from windnd import hook_dropfiles
+        hook_dropfiles(self, func=func)
+
 
 class DevToplevel(tk.Toplevel, DevWindow):
-    def __init__(self, master: tk.Tk = None, title: str = ""):
+    def __init__(self, master:tk.Tk, title: str = "", size=(630,300), icon=Icon_Empty):
         super(DevToplevel, self).__init__(master=master)
         self.title(title)
-        self.geometry("630x300")
-        self.iconbitmap(Icon_Empty)
+        self.geometry(f"{size[0]}x{size[1]}")
+        self.iconbitmap(icon)
 
 
 class DevPopup(DevToplevel):
@@ -1634,6 +1718,8 @@ class DevTooltip(DevToplevel):
 
 
 if __name__ == '__main__':
-    Window = DevWindow()
-    Manage = DevManage(Window)
-    Window.mainloop()
+    root = DevWindow()
+    tray = DevTray(root, icon=ICON_APPLICATION, icon_mode="load")
+    DevNotification(title="demo", message="你好，我是消息提示").show()
+    tray.show()
+    root.mainloop()
\ No newline at end of file
